@@ -6,6 +6,8 @@ use Fennec::Assert;
 use Fennec::Output::Result;
 use Scalar::Util qw/blessed reftype/;
 use Carp;
+our $DIFF;
+BEGIN { $DIFF = eval 'require String::Diff; 1' ? 1 : 0 }
 
 tester( $_ ) for qw/is isnt like unlike can_ok isa_ok is_deeply advanced_is/;
 
@@ -15,7 +17,7 @@ sub is($$;$) {
     result(
         pass => !$err,
         name => $name,
-        $err ? ( stdout => [ $err ]) : (),
+        $err ? ( stderr => [ $err ]) : (),
     );
 }
 
@@ -25,7 +27,7 @@ sub isnt($$;$) {
     result(
         pass => $err ? 1 : 0,
         name => $name,
-        $err ? () : ( stdout => [ "Got: $got", "Wanted: Anything else" ]),
+        $err ? () : ( stderr => [ "Got: $got", "Wanted: Anything else" ]),
     );
 }
 
@@ -36,7 +38,7 @@ sub like($$;$) {
     result(
         pass => $ok,
         name => $name,
-        $ok ? () : ( stdout => [ "$thing does not match $check" ]),
+        $ok ? () : ( stderr => [ "$thing does not match $check" ]),
     );
 }
 
@@ -47,7 +49,7 @@ sub unlike($$;$) {
     result(
         pass => $ok,
         name => $name,
-        $ok ? () : ( stdout => [ "$thing matches $check (it shouldn't)" ]),
+        $ok ? () : ( stderr => [ "$thing matches $check (it shouldn't)" ]),
     );
 }
 
@@ -57,13 +59,13 @@ sub can_ok(*;@) {
     return result(
         pass => 0,
         name => $name,
-        stdout => ["$thing is an unblessed reference"],
+        stderr => ["$thing is an unblessed reference"],
     ) if ref( $thing ) && !blessed( $thing );
     my @err = map { $thing->can( $_ ) ? () : "$thing cannot $_"} @stuff;
     result(
         pass => @err ? 0 : 1,
         name => $name,
-        stdout => \@err,
+        stderr => \@err,
     );
 }
 
@@ -73,13 +75,13 @@ sub isa_ok(*@) {
     return result(
         pass => 0,
         name => $name,
-        stdout => ["$thing is an unblessed reference"],
+        stderr => ["$thing is an unblessed reference"],
     ) if ref( $thing ) && !blessed( $thing );
     my @err = map { $thing->isa( $_ ) ? () : "$thing is not a $_"} @stuff;
     result(
         pass => @err ? 0 : 1,
         name => $name,
-        stdout => \@err,
+        stderr => \@err,
     );
 }
 
@@ -97,7 +99,7 @@ sub advanced_is {
     result(
         pass => @err ? 0 : 1,
         name => $name || undef,
-        stdout => \@err,
+        stderr => \@err,
     );
 }
 
@@ -106,6 +108,8 @@ sub compare($$;$) {
     return ("Not enough arguments")
         unless @_ > 1;
 
+    return if !defined( $have ) && !defined( $want );
+
     if ( !defined( $have ) || !defined( $want )) {
         return (
             "Expected: '"
@@ -116,13 +120,14 @@ sub compare($$;$) {
         ) if defined( $have ) || defined( $want );
     }
 
+    return SCALAR_compare( \$have, \$want, $specs )
+        unless ref( $want ) || ref( $have );
+
     my $haveref = reftype( $have ) || $have || "undef";
     my $wantref = reftype( $want ) || $want || "undef";
     return ( "Expected: '$wantref' Got: '$haveref'" )
         unless( "$haveref" eq "$wantref" );
 
-    return unless ref( $have ) && ref( $want );
-
     my @err;
     push @err => compare_bless( $have, $want )
         if $specs->{ bless };
@@ -171,6 +176,9 @@ sub SCALAR_compare {
     my $bad = (!$have && $want) || (!$want && $have);
     return if !$bad && "$have" eq "$want";
 
+    if ( $DIFF && defined( $want ) && defined( $have )) {
+        ( $want, $have ) = String::Diff::diff( $want, $have );
+    }
     $want = 'undef' unless defined( $want );
     $have = 'undef' unless defined( $have );
     return ( "Expected: '$want' Got: '$have'" );
@@ -179,6 +187,7 @@ sub SCALAR_compare {
 sub CODE_compare {
     my ( $have, $want, $specs ) = @_;
     return if $specs->{ no_code_checks };
+    print STDERR "C\n";
     my $msg = "Expected: '$want' Got: '$have'";
     return $msg unless $have == $want;
 }
