@@ -7,8 +7,21 @@ use base 'Fennec::Handler';
 
 sub init {
     my $self = shift;
+
     $self->{ out_std } ||= sub { print STDOUT "$_\n" for @_ };
-    $self->{ out_err } ||= sub { print STDERR "$_\n" for @_ };
+
+    my $harness = $ENV{HARNESS_ACTIVE};
+    my $verbose = $ENV{HARNESS_IS_VERBOSE};
+    # If we have a non-verbose harness then output the errors to STDERR so that
+    # they are seen. Outside of a harness, or in verbose mode the error output
+    # is sent to STDOUT so that the error message appear at or near the result
+    # that generated them.
+    if ( $harness && !$verbose ) {
+        $self->{ out_err } ||= sub { print STDERR "$_\n" for @_ };
+    }
+    else {
+        $self->{ out_err } ||= $self->{ out_std };
+    }
 }
 
 sub count {
@@ -32,7 +45,14 @@ sub handle {
         return;
     }
     return $self->result( $item ) if $item->isa( 'Fennec::Output::Result' );
-    return $self->stdout( @{ $item->stdout }) if $item->isa( 'Fennec::Output::Diag' );
+    if ( $item->isa( 'Fennec::Output::Diag' )) {
+        $self->stderr( @{ $item->stderr }) if $item->stderr;
+        if ( $item->stdout ) {
+            $self->stdout( @{ $item->stdout });
+            warn "Diag with stdout is deprecated\n";
+        }
+        return;
+    }
     warn "Unhandled output type: $item";
 }
 
@@ -42,8 +62,26 @@ sub result {
     return unless $result;
 
     my $out = (($result->pass || $result->skip) ? 'ok ' : 'not ok ' ) . $self->count . " -";
-    $out .= $result->benchmark ? sprintf( " [%7.2f]", $result->benchmark->[0])
-                               : " [  N/A  ]";
+    my $bma = $result->benchmark;
+    my $bm = $bma ? $bma->[0] : "N/A  ";
+    my $template = '[% 6s]';
+
+    # If we got a number (including -e notation)
+    if ( $bm =~ m/^[\d\.e\-]+$/ ) {
+        if ( $bm >= 100 ) {
+            $bm = int( $bm );
+            $template = '[%06s]';
+        }
+        elsif ($bm < 10) {
+            $template = '[%1.4f]';
+        }
+        elsif ( $bm < 100 ) {
+            $template = '[%2.3f]';
+        }
+    }
+
+    $out .= sprintf( " $template", $bm );
+
     $out .= " " . $result->name if $result->name;
     if ( my $todo = $result->todo ) {
         $out .= " # TODO $todo";
@@ -56,14 +94,17 @@ sub result {
         if ( $result->file ) {
             my $error = "Test failure at " . $result->file;
             $error .= " line " . $result->line if $result->line;
-            $self->stdout( $error );
+            $self->stderr( $error );
         }
         $self->stderr( "Workflow Stack: " . join( ', ', @{ $result->workflow_stack }))
             if $result->workflow_stack;
     }
-    my $stdout = $result->stdout;
-    return unless $stdout;
-    $self->stdout( $_ ) for @$stdout
+    if( my $stdout = $result->stdout ) {
+        $self->stdout( $_ ) for @$stdout;
+    }
+    if( my $stderr = $result->stderr ) {
+        $self->stderr( $_ ) for @$stderr;
+    }
 }
 
 sub stdout {
@@ -87,6 +128,15 @@ sub finish {
     $self->output( 'out_std', '1..' . ($self->count - 1));
 }
 
+sub fennec_error {
+    my $self = shift;
+    for my $msg ( @_ ) {
+        my $out = "not ok " . $self->count . " - Fennec Internal error";
+        $self->stdout( $out );
+        $self->stderr( $msg );
+    }
+}
+
 1;
 
 =head1 AUTHORS
