@@ -10,6 +10,9 @@ use Fennec::Workflow;
 use Try::Tiny;
 
 use Scalar::Util qw/blessed/;
+use Fennec::Util::Alias qw/
+    Fennec::Runner
+/;
 
 our @ANY_ACCESSORS = qw/ skip todo name file line/;
 our @SIMPLE_ACCESSORS = qw/ pass benchmark /;
@@ -40,6 +43,7 @@ sub new {
             $TODO ? ( todo => $TODO ) : (),
             %proto,
             pass => $pass ? 1 : 0,
+            $proto{'benchmark'} ? () : (benchmark => Runner->benchmark() || undef),
         },
         $class
     );
@@ -68,35 +72,35 @@ for my $any_accessor ( @ANY_ACCESSORS ) {
 for my $type ( qw/workflow testfile testset/ ) {
     my $fail = sub {
         my $class = shift;
-        my ( $item, @stdout ) = @_;
+        my ( $item, @stderr ) = @_;
         $class->new(
             pass => 0,
             $type => $item,
             $item->can( 'name' ) ? ( name => $item->name ) : (),
-            stdout => \@stdout,
+            stderr => \@stderr,
         )->write;
     };
     my $pass = sub {
         my $class = shift;
-        my ( $item, $benchmark, @stdout ) = @_;
+        my ( $item, $benchmark, @stderr ) = @_;
         $class->new(
             pass => 1,
             $type => $item,
             name => $item->name,
             benchmark => $benchmark,
-            stdout => \@stdout,
+            stderr => \@stderr,
         )->write;
     };
     my $skip = sub {
         my $class = shift;
-        my ( $item, $reason, @stdout ) = @_;
+        my ( $item, $reason, @stderr ) = @_;
         $reason ||= $item->skip || "no reason";
         $class->new(
             pass => 1,
             $type => $item,
             name => $item->name,
             skip => $reason,
-            stdout => \@stdout,
+            stderr => \@stderr,
         )->write;
     };
     no strict 'refs';
