@@ -23,7 +23,7 @@ use List::Util qw/shuffle/;
 use Time::HiRes qw/time/;
 use Benchmark qw/timeit :hireswallclock/;
 
-Accessors qw/files p_files p_tests threader ignore random pid parent_pid collector search default_asserts default_workflows/;
+Accessors qw/files p_files p_tests threader ignore random pid parent_pid collector search default_asserts default_workflows _benchmark_time/;
 
 our $SINGLETON;
 
@@ -41,7 +41,7 @@ sub init {
 
     my $collector_class = delete $proto{ collector } || 'Files';
     $collector_class = 'Fennec::Collector::' . $collector_class;
-    eval "require $collector_class; 1" || die( @_ );
+    eval "require $collector_class; 1" || die( $@ );
     my $collector = $collector_class->new( @$handlers );
 
     my $ignore = delete $proto{ ignore };
@@ -143,6 +143,19 @@ sub run_with_collector {
     return $code->();
 }
 
+sub reset_benchmark {
+    my $self = shift;
+    return $self->_benchmark_time( time )
+}
+
+sub benchmark {
+    my $self = shift;
+    my $old = $self->_benchmark_time;
+    return unless $old;
+    my $new = $self->reset_benchmark;
+    return [( $new - $old )];
+}
+
 1;
 
 =head1 AUTHORS
